"use strict";var s=function(r,t){return function(){return t||r((t={exports:{}}).exports,t),t.exports}};var i=s(function(p,e){
var c=require('@stdlib/assert-is-array/dist');function n(r){return typeof r=="object"&&r!==null&&!c(r)}e.exports=n
});var o=i();module.exports=o;
/** @license Apache-2.0 */
//# sourceMappingURL=index.js.map
